use eframe::egui::Pos2;
use egui_plot::{Line, PlotPoint, PlotPoints, PlotUi};

use crate::{
    application::Application,
    geometry::{elements::circle::Circle, DrawableRaw},
};

use super::{draw_on_plot_canvas, CanvasColour, PlotDrawer};

pub fn draw_geometries_(ui: &mut PlotUi, app: &mut Application) {
    for (file_name, geo) in &app.outlines {
        let selected = &app.selection == file_name;

        // draw outline path
        for path in geo.paths().iter() {
            draw_on_plot_canvas(
                ui,
                PlotDrawer::Closure(&|ui| {
                    // draw outline path
                    let mut points = path
                        .iter()
                        .map(|p| [p.x(), p.y()])
                        .collect::<Vec<[f64; 2]>>();

                    // calculate line width according to zoom factor
                    let transform = ui.transform();
                    let p1: Pos2 = transform.position_from_point(&PlotPoint::from(points[0]));
                    let p2: Pos2 = transform.position_from_point(&PlotPoint::from([
                        points[0][0] - geo.stroke as f64,
                        points[0][1],
                    ]));
                    let width = (p1.x - p2.x).abs();

                    points.push(points[0]);
                    points.push(points[1]);
                    let line = Line::new(PlotPoints::from(points))
                        .width(width)
                        .color(CanvasColour::Outline.as_colour32(selected));

                    ui.line(line)
                }),
            );
        }

        // draw point shapes
        for point in geo.points().iter() {
            draw_on_plot_canvas(
                ui,
                PlotDrawer::Closure(&|ui| {
                    let circle = Circle::new(*point, geo.stroke.into(), None);
                    circle.draw_egui_plot(ui, CanvasColour::Outline, selected);
                }),
            );
        }
    }
}
