use egui_plot::{Line, PlotPoints, PlotUi};

use crate::{
    application::Application,
    geometry::{ClipperPaths, DrawableRaw},
};

use super::{draw_on_plot_canvas, CanvasColour, PlotDrawer};

pub fn draw_gerbers_(ui: &mut PlotUi, app: &mut Application) {
    for (file_name, (_, geo)) in &app.gerbers {
        let selected = &app.selection == file_name;

        // draw apertures
        for geometry in geo.apertures.iter() {
            draw_on_plot_canvas(
                ui,
                PlotDrawer::Drawable((geometry, CanvasColour::Copper, selected)),
            );
        }

        // draw lines
        for line in geo.paths.iter() {
            draw_on_plot_canvas(
                ui,
                PlotDrawer::Closure(&|ui| line.draw_egui_plot(ui, CanvasColour::Copper, selected)),
            );
        }

        // draw conductor outlines
        for net in &geo.united_nets.conductors {
            draw_paths_outline(ui, &net.outline, selected);
        }

        // draw isolated aperture outlines
        for element in &geo.united_nets.isolated_apertures {
            draw_paths_outline(ui, &element.to_paths(), selected);
        }
    }
}

fn draw_paths_outline(ui: &mut PlotUi, paths: &ClipperPaths, selected: bool) {
    for path in paths.iter() {
        if !path.is_empty() {
            let mut points = path
                .iter()
                .map(|p| [p.x(), p.y()])
                .collect::<Vec<[f64; 2]>>();

            points.push(points[0]);
            let line = Line::new(PlotPoints::from(points))
                .color(CanvasColour::CopperOutline.as_colour32(selected));

            ui.line(line)
        }
    }
}
