pub mod excellons;
pub mod geometries;
pub mod gerbers;

use eframe::egui::{Color32, Ui};
use egui_plot::PlotUi;
use excellons::draw_excellons_;
use geometries::draw_geometries_;
use gerbers::draw_gerbers_;

use crate::geometry::elements::Element;

use super::Application;

const COPPER_COLOR: Color32 = Color32::from_rgb(0xCA, 0xF6, 0x8F);
const COPPER_COLOR_SELECTED: Color32 = Color32::YELLOW;
const COPPER_OUTLINE: Color32 = Color32::BLACK;
const COPPER_OUTLINE_SELECTED: Color32 = Color32::LIGHT_RED;
const EXCELLON_COLOR: Color32 = Color32::BROWN;
const EXCELLON_COLOR_SELECTED: Color32 = Color32::from_rgba_premultiplied(65, 42, 42, 128);
const OUTLINE_COLOR: Color32 = Color32::DARK_BLUE;
const OUTLINE_COLOR_SELECTED: Color32 = Color32::from_rgba_premultiplied(0, 0, 139, 128);

#[derive(Debug, Clone, Copy)]
pub enum CanvasColour {
    Copper,
    CopperOutline,
    Excellon,
    Outline,
}

impl CanvasColour {
    pub fn as_colour32(&self, selected: bool) -> Color32 {
        match (self, selected) {
            (CanvasColour::Copper, true) => COPPER_COLOR_SELECTED,
            (CanvasColour::Copper, false) => COPPER_COLOR,
            (CanvasColour::CopperOutline, true) => COPPER_OUTLINE_SELECTED,
            (CanvasColour::CopperOutline, false) => COPPER_OUTLINE,
            (CanvasColour::Excellon, true) => EXCELLON_COLOR_SELECTED,
            (CanvasColour::Excellon, false) => EXCELLON_COLOR,
            (CanvasColour::Outline, true) => OUTLINE_COLOR_SELECTED,
            (CanvasColour::Outline, false) => OUTLINE_COLOR,
        }
    }
}

pub fn draw_canvas(ui: &mut Ui, app: &mut Application) {
    egui_plot::Plot::new("ApplicationPlot")
        // .view_aspect(2.0)
        .data_aspect(1.0)
        .show(ui, |plot_ui| {
            draw_gerbers_(plot_ui, app);
            draw_excellons_(plot_ui, app);
            draw_geometries_(plot_ui, app);
        });
}

pub enum PlotDrawer<'a> {
    Drawable((&'a Element, CanvasColour, bool)),
    Closure(&'a dyn Fn(&mut PlotUi)),
}

fn draw_on_plot_canvas(ui: &mut PlotUi, drawer: PlotDrawer) {
    match drawer {
        PlotDrawer::Drawable((t, colour, selected)) => t.draw_egui_plot(ui, colour, selected),
        PlotDrawer::Closure(fun) => fun(ui),
    }
}
