mod canvas;
mod egui;
mod errors;
pub mod panels;

use std::collections::HashMap;

use crate::{
    excellon::drills::Drills,
    geometry::{Geometry, Unit},
    outline_geometry::OutlineGeometry,
    resources::ResourceLoader,
};

pub use canvas::CanvasColour;

pub struct Application<'a> {
    resources: ResourceLoader<'a>,
    gerbers: HashMap<String, (String, Geometry)>,
    outlines: HashMap<String, OutlineGeometry>,
    excellons: HashMap<String, (String, Drills)>,
    selection: String,
    variables: Variables,
}

#[derive(Debug, Default)]
pub struct Variables {
    laser_line_width: f32,
    units: Unit,
}

impl<'a> Application<'a> {
    pub fn new() -> Self {
        Self {
            resources: ResourceLoader::new(),
            gerbers: HashMap::new(),
            outlines: HashMap::new(),
            excellons: HashMap::new(),
            selection: "".into(),
            variables: Variables::default(),
        }
    }
}
