use std::collections::hash_map::Entry;

use eframe::egui::Ui;

use crate::{application::Application, geometry::ClipperPath, outline_geometry::OutlineGeometry};

use super::HOLE_MARK_DIAMETER;

pub fn show_excellon_actions(ui: &mut Ui, app: &mut Application) {
    if app.excellons.contains_key(&app.selection) {
        match app.excellons.entry(app.selection.to_string()) {
            Entry::Occupied(c) => {
                let mut deletion_request = false;
                let (name, drill) = c.get();
                if ui.button("Delete").clicked() {
                    deletion_request = true;
                }
                ui.horizontal(|ui| {
                    if ui.button("Generate cut out").clicked() {
                        let path = drill
                            .holes
                            .iter()
                            .map(|hole| hole.outline.clone())
                            .collect::<Vec<ClipperPath>>()
                            .into();
                        app.outlines.insert(
                            format!("{name}-CutOut"),
                            OutlineGeometry::new_no_inflate(&path, 0.1, app.variables.units, name),
                        );
                    }
                    if ui.button("Generate hole mark").clicked() {
                        app.outlines.insert(
                            format!("{name}-HoleMark"),
                            OutlineGeometry::drill_marker(
                                drill,
                                HOLE_MARK_DIAMETER,
                                app.variables.units,
                                name,
                            ),
                        );
                    }
                });

                if deletion_request {
                    c.remove();
                }
            }
            Entry::Vacant(_) => unreachable!(),
        }
    }
}
