use std::collections::hash_map::Entry;

use eframe::egui::{ComboBox, Ui};

use crate::{application::Application, export::svg::SVGConverter};

pub fn show_geometry_actions(ui: &mut Ui, app: &mut Application) {
    if app.outlines.contains_key(&app.selection) {
        match app.outlines.entry(app.selection.to_string()) {
            Entry::Occupied(mut c) => {
                let mut deletion_request = false;
                let isolated_tracks = c.get_mut();

                if ui.button("Delete").clicked() {
                    deletion_request = true;
                }

                ui.horizontal(|ui| {
                    ui.label("BoundingBox");
                    let id = ui.make_persistent_id("BoundingBoxSelection");
                    ComboBox::new(id, "")
                        .selected_text(format!("{:?}", isolated_tracks.bounds_from))
                        .show_ui(ui, |ui| {
                            for (key, (name, _)) in app.gerbers.iter() {
                                if ui
                                    .selectable_value(
                                        &mut isolated_tracks.bounds_from,
                                        name.into(),
                                        name,
                                    )
                                    .clicked()
                                {
                                    if let Some((_, box_geo)) = app.gerbers.get(key) {
                                        isolated_tracks.bounding_box = box_geo.united_nets.bounds();
                                    }
                                }
                            }
                        });

                    if ui.button("Save as SVG").clicked() {
                        if let Some(path) = rfd::FileDialog::new()
                            .set_title("Save as SVG")
                            .set_file_name(app.selection.to_string())
                            .add_filter("SVG", &["svg", "SVG"])
                            .save_file()
                        {
                            SVGConverter::export(isolated_tracks, &path);
                        }
                    }
                });

                if deletion_request {
                    c.remove();
                }
            }
            Entry::Vacant(_) => unreachable!(),
        }
    }
}
