use std::collections::hash_map::Entry;

use eframe::egui::{DragValue, Ui};

use crate::{application::Application, outline_geometry::OutlineGeometry};

pub fn show_gerber_actions(ui: &mut Ui, app: &mut Application) {
    if app.gerbers.contains_key(&app.selection) {
        match app.gerbers.entry(app.selection.to_string()) {
            Entry::Occupied(c) => {
                let mut deletion_request = false;
                let (name, gerber) = c.get();

                if ui.button("Delete").clicked() {
                    deletion_request = true;
                }
                ui.horizontal(|ui| {
                    ui.add(
                        DragValue::new(&mut app.variables.laser_line_width)
                            .range(0.1..=10.)
                            .speed(0.1)
                            .suffix(gerber.units),
                    );

                    if ui.button("Generate Isolation").clicked() {
                        app.outlines.insert(
                            format!("{name}-Iso"),
                            OutlineGeometry::new(
                                &gerber.united_nets,
                                app.variables.laser_line_width,
                                gerber.units,
                                name,
                            ),
                        );
                    }
                });

                if deletion_request {
                    c.remove();
                }
            }
            Entry::Vacant(_) => unreachable!(),
        }
    }
}
