use std::collections::HashMap;

use crate::geometry::{point::Point, Unit};

#[derive(Debug, PartialEq)]
// Representation of Gerber document
pub struct ExcellonDoc {
    // // unit type, defined once per document
    pub units: Unit,
    pub zeroes: Zeroes,
    // // format specification for coordinates, defined once per document
    // pub format_specification: Option<CoordinateFormat>,
    // /// map of apertures which can be used in draw commands later on in the document.
    /// map of tools which can be used in draw commands later on in the document.
    pub tools: HashMap<u32, Tool>,
    pub commands: Vec<Command>,
}

impl ExcellonDoc {
    pub fn new() -> Self {
        Self {
            units: Unit::Inches,
            zeroes: Zeroes::Leading,
            tools: HashMap::new(),
            commands: Vec::new(),
        }
    }
}

#[derive(Debug, PartialEq, Clone, Copy)]
pub enum Zeroes {
    Leading,
    Trailing,
}

#[derive(Debug, PartialEq)]
pub struct Tool {
    pub diameter: f64,
}

impl Tool {
    pub fn new(diameter: f64) -> Self {
        Self { diameter }
    }
}

#[derive(Debug, PartialEq)]
pub enum Command {
    FunctionCode(FunctionCode),
}

#[derive(Debug, PartialEq)]
pub enum FunctionCode {
    EndOfFile,
    SelectTool(u32),
    Comment(String),
    Drill(Point),
}
