use tracing::debug;

use crate::{
    excellon::doc::{Command, FunctionCode},
    geometry::{elements::circle::Circle, Unit},
};

use super::doc::ExcellonDoc;

pub struct Drills {
    pub holes: Vec<Circle>,
    pub units: Unit,
}

impl From<ExcellonDoc> for Drills {
    fn from(doc: ExcellonDoc) -> Self {
        // working variables
        let mut selected_tool = None;
        let mut holes = Vec::new();

        for command in &doc.commands {
            match command {
                Command::FunctionCode(code) => match code {
                    FunctionCode::EndOfFile => {}
                    FunctionCode::SelectTool(id) => selected_tool = doc.tools.get(id),
                    FunctionCode::Comment(c) => debug!(c),
                    FunctionCode::Drill(p) => {
                        if let Some(tool) = selected_tool {
                            holes.push(Circle::new(*p, tool.diameter, None))
                        }
                    }
                },
            }
        }

        Self {
            units: doc.units,
            holes,
        }
    }
}

impl Drills {
    pub fn into_unit(self, unit: Unit) -> Self {
        Self {
            units: unit,
            holes: self
                .holes
                .into_iter()
                .map(|hole| hole.into_unit(self.units, unit))
                .collect(),
        }
    }
}
