use eframe::egui::Stroke;
use gerber_types::OutlinePrimitive;

use crate::{
    application::CanvasColour,
    geometry::{
        elements::macro_decimal_to_f64, point::Point, ClipperPath, ClipperPaths, DrawableRaw, Unit,
    },
};

#[derive(Debug, Clone)]
pub struct Polygon {
    points: Vec<Point>,
}

impl Polygon {
    pub fn new(points: &[Point]) -> Self {
        Self {
            points: points.to_vec(),
        }
    }

    pub fn into_unit(self, origin: Unit, to: Unit) -> Self {
        Self {
            points: self
                .points
                .iter()
                .map(|p| p.into_unit(origin, to))
                .collect(),
        }
    }

    pub fn from_macro(ap_macro: &OutlinePrimitive, variables: &[f64], target: Point) -> Self {
        Self {
            points: ap_macro
                .points
                .iter()
                .map(|(x, y)| {
                    Point::new(
                        macro_decimal_to_f64(x, variables),
                        macro_decimal_to_f64(y, variables),
                    ) + target
                })
                .collect(),
        }
    }
}

impl DrawableRaw for Polygon {
    fn canvas_pos(&self) -> Point {
        // self.position
        todo!()
    }

    fn draw_egui_plot(&self, ui: &mut egui_plot::PlotUi, colour: CanvasColour, selected: bool) {
        let points: Vec<[f64; 2]> = self.points.iter().map(|p| [p.x(), p.y()]).collect();

        ui.polygon(
            egui_plot::Polygon::new(points)
                .fill_color(colour.as_colour32(selected))
                .stroke(Stroke::NONE),
        );
    }

    fn to_paths(&self) -> ClipperPaths {
        ClipperPaths::new(vec![self.outline()])
    }

    fn outline(&self) -> ClipperPath {
        ClipperPath::new(self.points.iter().map(|p| p.into()).collect())
    }
}
