#![cfg_attr(not(debug_assertions), windows_subsystem = "windows")] // hide console window on Windows in release

mod application;
mod excellon;
mod export;
mod geometry;
mod gerber;
mod outline_geometry;
mod resources;

use application::Application;

use eframe::egui::{self, IconData};
use tracing_subscriber::{filter, layer::SubscriberExt, util::SubscriberInitExt, Layer};

const APP_NAME: &str = "Outlinify";
const ICON: &[u8] = include_bytes!("../resources/icon.png");

fn main() -> eframe::Result {
    let stdout_log = tracing_subscriber::fmt::layer()
        .pretty()
        .with_filter(filter::filter_fn(|metadata| {
            metadata.target().starts_with(env!("CARGO_CRATE_NAME"))
        }))
        .with_filter(filter::LevelFilter::DEBUG);

    // Register subscriptions
    tracing_subscriber::registry().with(stdout_log).init();

    let application = Application::new();

    let options = eframe::NativeOptions {
        viewport: egui::ViewportBuilder::default()
            .with_inner_size([900.0, 700.0])
            .with_icon(load_icon()),
        ..Default::default()
    };

    eframe::run_native(
        APP_NAME,
        options,
        Box::new(|cc| {
            // This gives us image support:
            egui_extras::install_image_loaders(&cc.egui_ctx);

            Ok(Box::new(application))
        }),
    )
}

fn load_icon() -> IconData {
    let (icon_rgba, icon_width, icon_height) = {
        let icon = ICON;
        let image = image::load_from_memory(icon)
            .expect("Failed to open icon path")
            .into_rgba8();
        let (width, height) = image.dimensions();
        let rgba = image.into_raw();
        (rgba, width, height)
    };

    IconData {
        rgba: icon_rgba,
        width: icon_width,
        height: icon_height,
    }
}
